ORCA4 Neutrino analysis
-----------------------

Config files for neutrino analysis, done by Daniel Guderian (2021).

Used versions:

- orcanet 0.13.6

- medgeconv 1.0.1

Notes
-----

- medgeconv config format has changed slightly in version 2.X, adjustment required

- I trained the regression networks on different datasets: Muon CC up to 50GeV + shower neutrinos for the energy reco and all kinds of events for the direction reconstruction.
